@@ -14,7 +14,7 @@
 #' @param tolerance Maximum distance allowed between the curve and its
 #'   approximation. For more details, please refer to [the documentation of the
 #'   underlying Rust
-#'   library](https://docs.rs/lyon/0.17.5/lyon/#what-is-the-tolerance-variable-in-these-examples).
+#'   library](https://docs.rs/lyon_geom/latest/lyon_geom/#flattening).
 #'
 #' @param line_width Line width of strokes.
 #'
@@ -35,36 +35,40 @@
 #'   weight <- available_fonts$weight[1]
 #'   style  <- available_fonts$style[1]
 #'
-#'   # string2path() converts a text to paths
-#'   d_path <- string2path("TEXT", family, weight, style)
-#'   if (nrow(d_path) > 0) {
-#'     plot(d_path$x, d_path$y)
-#'     for (p in split(d_path, d_path$path_id)) {
-#'       lines(p$x, p$y)
+#'   # Not all fonts can handle "TEXT" glyph. Stop here if it's the case.
+#'   skip <- inherits(try(string2path("TEXT", family, weight, style)), "try-error")
+#'   if (!skip) {
+#'     # string2path() converts a text to paths
+#'     d_path <- string2path("TEXT", family, weight, style)
+#'     if (nrow(d_path) > 0) {
+#'       plot(d_path$x, d_path$y)
+#'       for (p in split(d_path, d_path$path_id)) {
+#'         lines(p$x, p$y)
+#'       }
 #'     }
-#'   }
-#'
-#'   # string2stroke() converts a text to strokes
-#'   d_stroke <- string2stroke("TEXT", family, weight, style)
-#'   if (nrow(d_stroke) > 0) {
-#'     plot(d_stroke$x, d_stroke$y)
-#'
-#'     # The stroke is split into triangles, which can be distinguished by `triangle_id`
-#'     set.seed(2)
-#'     for (p in split(d_stroke, d_stroke$triangle_id)) {
-#'       polygon(p$x, p$y, col = rgb(runif(1), runif(1), runif(1), 0.8))
+#'  
+#'     # string2stroke() converts a text to strokes
+#'     d_stroke <- string2stroke("TEXT", family, weight, style)
+#'     if (nrow(d_stroke) > 0) {
+#'       plot(d_stroke$x, d_stroke$y)
+#'  
+#'       # The stroke is split into triangles, which can be distinguished by `triangle_id`
+#'       set.seed(2)
+#'       for (p in split(d_stroke, d_stroke$triangle_id)) {
+#'         polygon(p$x, p$y, col = rgb(runif(1), runif(1), runif(1), 0.8))
+#'       }
 #'     }
-#'   }
-#'
-#'   # string2fill() converts a text to filled polygons
-#'   d_fill <- string2fill("TEXT", family, weight, style)
-#'   if (nrow(d_fill) > 0) {
-#'     plot(d_fill$x, d_fill$y)
-#'
-#'     # The polygon is split into triangles, which can be distinguished by `triangle_id`
-#'     set.seed(2)
-#'     for (p in split(d_fill, d_fill$triangle_id)) {
-#'       polygon(p$x, p$y, col = rgb(runif(1), runif(1), runif(1), 0.8))
+#'  
+#'     # string2fill() converts a text to filled polygons
+#'     d_fill <- string2fill("TEXT", family, weight, style)
+#'     if (nrow(d_fill) > 0) {
+#'       plot(d_fill$x, d_fill$y)
+#'  
+#'       # The polygon is split into triangles, which can be distinguished by `triangle_id`
+#'       set.seed(2)
+#'       for (p in split(d_fill, d_fill$triangle_id)) {
+#'         polygon(p$x, p$y, col = rgb(runif(1), runif(1), runif(1), 0.8))
+#'       }
 #'     }
 #'   }
 #' }
@@ -77,9 +81,6 @@ string2path <- function(
     font_style = c("normal", "italic", "oblique"),
     tolerance = 0.00005
 ) {
-  # TODO: remove when drop support for R < 4.1
-  text <- enc2utf8(text)
-
   if (is_font_file(font)) {
     if (!missing(font_weight) || !missing(font_style)) {
       cli::cli_warn("{.arg font_weight} and {.arg font_style} are ignored when extracting a font file.")
@@ -105,9 +106,6 @@ string2stroke <- function(
     tolerance = 0.00005,
     line_width = 0.03
 ) {
-  # TODO: remove when drop support for R < 4.1
-  text <- enc2utf8(text)
-
   if (is_font_file(font)) {
     if (!missing(font_weight) || !missing(font_style)) {
       cli::cli_warn("{.arg font_weight} and {.arg font_style} are ignored when extracting a font file.")
@@ -132,9 +130,6 @@ string2fill <- function(
     font_style = c("normal", "italic", "oblique"),
     tolerance = 0.00005
 ) {
-  # TODO: remove when drop support for R < 4.1
-  text <- enc2utf8(text)
-
   if (is_font_file(font)) {
     if (!missing(font_weight) || !missing(font_style)) {
       cli::cli_warn("{.arg font_weight} and {.arg font_style} are ignored when extracting a font file.")
